Validate Created Database
validate_database.RdUsed to validate databases created by `build_station_database`. This function will check for tables created within the database, count the number of records within each table, and print the first five observation records.